"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * RegExp Exclusion Example
 *
 * An example of using regular expressions to exclude conditions from test cases.
 * In this case, the benefits of IDE autocompletion are not available for patterns specified by regular expressions.
 */
const index_1 = require("../../index");
const domain = {
    "Given": {
        "Student": {
            "Course": [
                "Bachelor",
                "Master",
                "Doctor",
            ],
            "Grade": [
                "1",
                "2",
                "3",
                "4",
            ]
        }
    },
    "When": [
        "Try to login",
    ],
    "Then": [
        "Pass",
        "Fail",
        "Any",
    ],
};
const defaults = {
    "Given": {
        "Student": {
            "Course": "Bachelor",
            "Grade": "1",
        }
    },
    "When": "Try to login",
    "Then": "Any",
};
const exclusions = [
    {
        "Given.Student.Course": "Master",
        "Given.Student.Grade": /(3|4)/,
    },
    {
        "Given.Student.Course": "Doctor",
        "Given.Student.Grade": "4",
    },
];
const perspectives = [
    {
        "title": "Only Bachelors can login.",
        "constants": {},
        "variables": [
            "Given.Student.Course",
            "Given.Student.Grade",
        ],
        "expect": (test) => {
            if (test["Given.Student.Course"] === "Bachelor") {
                test["Then"] = "Pass";
            }
            else {
                test["Then"] = "Fail";
            }
            return test;
        }
    }
];
const tests = (0, index_1.generateTests)(domain, defaults, exclusions, perspectives);
console.log(tests);
